
#' Exact Confidence Limits After a Sequential Trial.
#'
#' Allows the user to compare different methods of calculating
#' exact upper and lower limits for a probability after a group sequential
#' trial.
#'
#' @name exact.n-package
#' @aliases exact.n
#' @docType package
#' @author Chris J. Lloyd
#' @references Lloyd, C.J. (2020) Exact confidence limits after a group
#' sequential single arm binary trial. Statistics in Medicine, Volume 38,
#' 2389-2399.
#' @keywords package
#' @examples
#'
#' \dontrun{
#' # For target size 0.25 and power 75% at a clinical difference 0.2
#' # assuming that p0 is between 0.4 and 0.5, what are the sample
#' # size options? First download the power library
#' fetch.data(alpha=0.025,delta=0.20)
#' # Then interrogate the library to find sample size solutions
#' # that achieve the target size and power.
#' main.function(alpha=0.025, delta=0.2, p0 = c(0.4,0.5),
#'               beta = 0.75, type = 2, plt = FALSE, out = (-1), b.lim = 5)
#' # The interrogation time is proportional to the range of p0 and could
#' # also take up to a minute. A single value of p0 will take a few seconds.
#' # The interrogation time is proportional to the range of p0 and could
#' # also take up to a minute. A single value of p0 will take a few seconds.
#' }



