% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.r
\name{ESTEP.rd}
\alias{ESTEP.rd}
\title{Calculate E-P-values based on LR statistic.}
\usage{
ESTEP.rd(n0, n1, psi = 0, J = NULL, dec.places = 10, prin = F)
}
\arguments{
\item{n0}{control sample size}

\item{n1}{treatment sample size}

\item{psi}{null value of risk difference p1-p0}

\item{J}{index of single data set if desired}

\item{dec.places}{number of decimal places of output t-values and p-values.}

\item{prin}{outputs expected time and progress of calculation}
}
\value{
A list with components \item{y0,y1}{data sets (scalar or vector)}
\item{oldP}{approximate p-value(s) before E-step} \item{T, P}{quasi-exact
P-value(s) and equivalent T-value(s)} \item{pmle}{profile ML estimates of
baseline probability} \item{index}{consistent code to select a single
outcome} \item{psi}{scalar null value of p1-p0}
}
\description{
Calculates all possible values of the E-P-value for testing p1-p0 greater
than a provided null value psi.
}
\details{
This function can take a long time for larger sample sizes. The computation
time is of order (n0*n1)^2.
}
\examples{

\dontrun{
n0=65
n1=82
y0=25
y1=41

# Approximate inferential quantities for this particular outcome
# lr.rd(n0,n1,Y0=y0,Y1=y1,psi=0) # Index of this data set is 2732

# The ESTEP p-value is close to exact and requires calculating all possible
# values of lr.rd p-values.
ESTEP.rd(n0,n1,psi=0,J=2732)

# Compute all possible E-p-values (can be time consuming)
# Calculation has been stored to pass CRAN check time limits
# all.evalues=ESTEP.rd(n0,n1,psi=0,prin=TRUE)
plot(all.evalues$oldP,all.evalues$P,
     xlab="approximate p-values",ylab="quasi-exact p-values")
}

}
\references{
C.J. Lloyd & R. Ripamonti (2021) A comprehensive open-source
library for exact required sample size in binary clinical trials.
Contemporary Clinical Trials 107. \doi{10.1016/j.cct.2021.106491}
}
\author{
Chris J. Lloyd
}
\keyword{internal}
